@@ -12,7 +12,7 @@ function(mask, cx)
     ## op <-  options('warn')
   	op <- par(no.readonly = TRUE) 
     options('warn'=-1)
-    cm   <- matrix(1:cl, nc=round(sqrt(cl)), byr=TRUE)
+    cm   <- matrix(1:cl, ncol=round(sqrt(cl)), byrow=TRUE)
     par(ask=TRUE)
     par(mfcol=dim(cm), mar=c(0, 0, 0, 0) + 0.1)
     ysim <- numeric(length(cx))
